<?php
/* (c) 2001 Marco Pratesi <pratesi@telug.it> */
$t = new Template();
$t->set_file(array("page" => "templates/footer.ihtml"));
include ("$CFG->localelangdir" . "/global-admin.inc.php");
$t->pparse("out", "page");
?>
